#!/bin/ksh
#> This script will apply the Cisco Adjunct (Switch) update
#> patch: 1.0.2.0.1
#> Usage: install.sh {-help | -install}
#

# Required values defined
export PATCH_VER=1.0.2.0.1
export START_DIR=`pwd`
export SOURCE_DIR=${FLEXPM_BASE}/patches/${PATCH_VER}
export FILESET="Interface.xml CiscoSwitch.xml CPU.xml MemoryPool.xml"
export FILESOURCE=${START_DIR}/fileset
export BACKUPDIR=${START_DIR}/BACKUP

# **************************************************************
# The following are 'standard' routines to be used before
# attempting to apply any upgrade/patch
# **************************************************************
# ***
# Check the essential environment settings have been defined before attempting
# any installation procedures.
# ***
function CheckEnvironment {

  # Check FLEXPM_HOME is defined 
  if [[ -z ${FLEXPM_HOME} || ! -d ${FLEXPM_HOME} ]]; then
    echo ""
    echo "Fail: Env variable FLEXPM_HOME must be set to appropriate dir before installation."
    echo ""
    exit 1;
  fi
  # Check CisSwitch_HOME is defined 
  if [[ -z ${CisSwitch_HOME} || ! -d ${CisSwitch_HOME} ]]; then
    echo ""
    echo "Fail: Env variable CisSwitch_HOME must be set to appropriate dir before installation."
    echo ""
    exit 1;
  fi
  # Check that the DB_CONNECT string is defined.
  if [[ -z ${DB_CONNECT} ]]; then
    echo ""
    echo "Fail: Env variable DB_CONNECT must be set to approriate database connection values."
    echo ""
    exit 1;
  fi
  # Check that the required files are in place
  if [[ ! -f ${START_DIR}/alter_tables.sql || ! -f ${START_DIR}/CiscoAdjunct.build ]]; then
    echo ""
    echo "Fail: Missing file(s) in ${START_DIR}"
    echo "      Files required:"
    echo "	    install.sh"
    echo "	    CiscoAdjunct.build"
    echo "	    alter_tables.sql"
    echo ""
    exit 1
  fi
  # Create a backup directory if possible.
  if [[ ! -d $BACKUPDIR ]]; then
    mkdir ${BACKUPDIR}
    if [ $? -ne 0 ]; then
      echo "Info: Unable to make backup directory ${BACKUPDIR}"
      echo "      Modified xml files will not be backed up."
    fi
  fi
}

# **************************************************************
# End of routines and start of main patch
# **************************************************************

# Check that the passed parameters are correct
if [[ $# -ne 1 ]]; then
  echo
  echo "Invalid number of arguments"
  echo
  echo "Usage : $0 {-help | -install}"
  echo
  exit;
fi

case $1 in
  -install)
    echo ""
    date +"+ Patch install started at %T, %D ..."
    echo ""

    # Check env settings
    echo ""
    echo "+ Checking environment ..."
    CheckEnvironment
    echo "+ Environment appears to be OK ..."
    echo ""

    echo "Registering Cisco Adjunct ${PATCH_VER} ..."
    chmod +x $FLEXPM_HOME/pm/adm/register
    register start ${START_DIR}/CiscoAdjunct.build

    ########################################################
    echo "+ Installing update..."
    ########################################################
    cd ${CisSwitch_HOME}/peik/xml
    for file in $FILESET
    do
      if [[ -f $file ]]
      then
        chmod +w $file
	if [[ -d ${BACKUPDIR} ]]
        then
          if [[ -f ${BACKUPDIR}/$file ]];
	  then
	    chmod +w ${BACKUPDIR}/$file
          fi;
          cp $file ${BACKUPDIR}
        fi;
      fi;
      cp ${FILESOURCE}/$file .
      chmod -w $file
    done
    cd ${START_DIR}

    sqlplus -s /nolog <<EOF
connect ${DB_CONNECT}
@alter_tables;
EOF



    echo "Completing registration ..."
    register complete ${START_DIR}/CiscoAdjunct.build

    cd ${START_DIR}

    date +"Patch is completed at %T, %D ....."
    break
    ;;
  -help)
    echo
    echo "Usage : $0 {-help | -install}"
    echo
    echo "-help      : Display this help text"
    echo "-install   : Install the patch"
    echo
    break
    ;;
  *)
    echo
    echo "Invalid argument supplied"
    echo
    echo "Usage : $0 {-help | -install}"
    echo
    break
    ;;
esac

